@@ -61,7 +61,7 @@ func TestOLMInstallation(t *testing.T) {
 				fmt.Sprintf("BUNDLE_IMAGE_NAME=%s", bundleImageName),
 				fmt.Sprintf("NAMESPACE=%s", ns),
 			),
-			"180s",
+			"300s",
 		)
 		// Refresh the test client to account for the newly installed CRDs
 		RefreshClient(t)
@@ -73,7 +73,7 @@ func TestOLMInstallation(t *testing.T) {
 			Should(Equal(olm.CSVPhaseSucceeded))
 		// Check the operator pod is running
 		g.Eventually(OperatorPodPhase(t, ctx, ns), TestTimeoutMedium).Should(Equal(corev1.PodRunning))
-		g.Eventually(OperatorImage(t, ctx, ns), TestTimeoutShort).Should(Equal(defaults.OperatorImage()))
+		g.Eventually(OperatorImage(t, ctx, ns), TestTimeoutShort).Should(Equal(operatorImage()))
 
 		integrationPlatform := v1.NewIntegrationPlatform(ns, "camel-k")
 		integrationPlatform.Spec.Build.Registry = v1.RegistrySpec{
@@ -112,3 +112,17 @@ func TestOLMInstallation(t *testing.T) {
 		g.Eventually(CRDs(t)).Should(BeNil())
 	})
 }
+
+func operatorImage() string {
+	return envOrDefault(fmt.Sprintf("%s:%s", defaults.ImageName, defaults.Version), "KAMEL_OPERATOR_IMAGE", "KAMEL_K_TEST_OPERATOR_CURRENT_IMAGE")
+}
+
+func envOrDefault(def string, envs ...string) string {
+	for i := range envs {
+		if val := os.Getenv(envs[i]); val != "" {
+			return val
+		}
+	}
+
+	return def
+}
