@@ -75,7 +75,6 @@ import (
 	"github.com/apache/camel-k/v2/e2e/support/util"
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
-	v1alpha1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1alpha1"
 	"github.com/apache/camel-k/v2/pkg/client"
 	"github.com/apache/camel-k/v2/pkg/cmd"
 	"github.com/apache/camel-k/v2/pkg/install"
@@ -101,8 +100,7 @@ const ciPID = "/tmp/ci-k8s-pid"
 // v1.Build,          v1.Integration
 // v1.IntegrationKit, v1.IntegrationPlatform, v1.IntegrationProfile
 // v1.Kamelet,  v1.Pipe,
-// v1alpha1.Kamelet, v1alpha1.KameletBinding
-const ExpectedCRDs = 9
+const ExpectedCRDs = 7
 
 // camel-k-operator,
 // camel-k-operator-events,
@@ -116,8 +114,7 @@ const ExpectedKubePromoteRoles = 7
 // camel-k-edit
 // camel-k-operator-custom-resource-definitions
 // camel-k-operator-bind-addressable-resolver
-// camel-k-operator-local-registry
-const ExpectedKubeClusterRoles = 4
+const ExpectedKubeClusterRoles = 3
 
 // camel-k-operator-openshift
 const ExpectedOSPromoteRoles = 1
@@ -499,7 +496,6 @@ func Logs(t *testing.T, ctx context.Context, ns, podName string, options corev1.
 }
 
 func StructuredLogs(t *testing.T, ctx context.Context, ns, podName string, options *corev1.PodLogOptions, ignoreParseErrors bool) ([]util.LogEntry, error) {
-
 	stream, err := TestClient(t).CoreV1().Pods(ns).GetLogs(podName, options).Stream(ctx)
 	if err != nil {
 		msg := "Error while reading container logs"
@@ -1944,7 +1940,7 @@ func PlatformByName(t *testing.T, ctx context.Context, ns string, name string) f
 
 func IntegrationProfileByName(t *testing.T, ctx context.Context, ns string, name string) func() *v1.IntegrationProfile {
 	return func() *v1.IntegrationProfile {
-		lst := v1.NewIntegrationProfileList()
+		lst := newIntegrationProfileList()
 		if err := TestClient(t).List(ctx, &lst, ctrl.InNamespace(ns)); err != nil {
 			failTest(t, err)
 		}
@@ -1957,6 +1953,16 @@ func IntegrationProfileByName(t *testing.T, ctx context.Context, ns string, name
 	}
 }
 
+// newIntegrationProfileList --.
+func newIntegrationProfileList() v1.IntegrationProfileList {
+	return v1.IntegrationProfileList{
+		TypeMeta: metav1.TypeMeta{
+			APIVersion: v1.SchemeGroupVersion.String(),
+			Kind:       v1.IntegrationProfileKind,
+		},
+	}
+}
+
 func CamelCatalog(t *testing.T, ctx context.Context, ns, name string) func() *v1.CamelCatalog {
 	return func() *v1.CamelCatalog {
 		cat := v1.CamelCatalog{}
@@ -1975,7 +1981,7 @@ func CamelCatalog(t *testing.T, ctx context.Context, ns, name string) func() *v1
 
 func IntegrationProfile(t *testing.T, ctx context.Context, ns string) func() *v1.IntegrationProfile {
 	return func() *v1.IntegrationProfile {
-		lst := v1.NewIntegrationProfileList()
+		lst := newIntegrationProfileList()
 		if err := TestClient(t).List(ctx, &lst, ctrl.InNamespace(ns)); err != nil {
 			failTest(t, err)
 		}
@@ -2235,7 +2241,6 @@ func CRDs(t *testing.T) func() []metav1.APIResource {
 			reflect.TypeOf(v1.IntegrationProfile{}).Name(),
 			reflect.TypeOf(v1.Kamelet{}).Name(),
 			reflect.TypeOf(v1.Pipe{}).Name(),
-			reflect.TypeOf(v1alpha1.KameletBinding{}).Name(),
 		}
 
 		versions := []string{"v1", "v1alpha1"}
