@@ -18,10 +18,9 @@ limitations under the License.
 package v1
 
 import (
+	"github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-
-	"github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 )
 
 const (
@@ -221,6 +220,8 @@ type Traits struct {
 	KnativeService *trait.KnativeServiceTrait `property:"knative-service" json:"knative-service,omitempty"`
 	// The configuration of Logging trait
 	Logging *trait.LoggingTrait `property:"logging" json:"logging,omitempty"`
+	// The configuration of Master trait
+	Master *trait.MasterTrait `property:"master" json:"master,omitempty"`
 	// The configuration of Mount trait
 	Mount *trait.MountTrait `property:"mount" json:"mount,omitempty"`
 	// The configuration of OpenAPI trait
@@ -261,8 +262,6 @@ type Traits struct {
 	// Deprecated: for backward compatibility.
 	Keda *TraitSpec `property:"keda" json:"keda,omitempty"`
 	// Deprecated: for backward compatibility.
-	Master *TraitSpec `property:"master" json:"master,omitempty"`
-	// Deprecated: for backward compatibility.
 	Strimzi *TraitSpec `property:"strimzi" json:"strimzi,omitempty"`
 	// Deprecated: for backward compatibility.
 	ThreeScale *TraitSpec `property:"3scale" json:"3scale,omitempty"`
@@ -433,10 +432,16 @@ type Flow struct {
 type RuntimeProvider string
 
 const (
-	// RuntimeProviderQuarkus Camel Quarkus runtime.
+	// RuntimeProviderQuarkus Camel K runtime (Quarkus based).
 	RuntimeProviderQuarkus RuntimeProvider = "quarkus"
+	// RuntimeProviderPlainQuarkus Camel Quarkus plain runtime.
+	RuntimeProviderPlainQuarkus RuntimeProvider = "plain-quarkus"
 )
 
+func (rt RuntimeProvider) IsQuarkusBased() bool {
+	return rt == RuntimeProviderQuarkus || rt == RuntimeProviderPlainQuarkus
+}
+
 // SourceSpec defines the configuration for one or more routes to be executed in a certain Camel DSL language.
 type SourceSpec struct {
 	// contains configuration related to the source code
@@ -497,18 +502,22 @@ const (
 	// LanguageJavaSource used for Java.
 	LanguageJavaSource Language = "java"
 	// LanguageGroovy used for Groovy.
+	// Deprecated: language no longer supported.
 	LanguageGroovy Language = "groovy"
 	// LanguageJavaScript  used for Javascript.
+	// Deprecated: language no longer supported.
 	LanguageJavaScript Language = "js"
 	// LanguageXML used for XML.
 	LanguageXML Language = "xml"
 	// LanguageKotlin used for Kotlin.
+	// Deprecated: language no longer supported.
 	LanguageKotlin Language = "kts"
 	// LanguageYaml used for YAML.
 	LanguageYaml Language = "yaml"
 	// LanguageKamelet used for Kamelets.
 	LanguageKamelet Language = "kamelet"
 	// LanguageJavaShell used for Java Shell.
+	// Deprecated: language no longer supported.
 	LanguageJavaShell Language = "jsh"
 )
 
