@@ -24,7 +24,6 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/apache/camel-k/v2/pkg/util/test"
 	"github.com/spf13/cobra"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -51,48 +50,48 @@ func addTestConfigCmd(options RootCmdOptions, rootCmd *cobra.Command, mock bool)
 			return nil
 		}
 	}
-	configCmd.Args = test.ArbitraryArgs
+	configCmd.Args = ArbitraryArgs
 	rootCmd.AddCommand(configCmd)
 	return configOptions
 }
 
 func TestConfigNonExistingFlag(t *testing.T) {
 	_, rootCmd, _ := initializeConfigCmdOptions(t, true)
-	_, err := test.ExecuteCommand(rootCmd, cmdConfig, "--nonExistingFlag")
+	_, err := ExecuteCommand(rootCmd, cmdConfig, "--nonExistingFlag")
 	require.Error(t, err)
 }
 
 func TestConfigDefaultNamespaceFlag(t *testing.T) {
 	configCmdOptions, rootCmd, _ := initializeConfigCmdOptions(t, true)
-	_, err := test.ExecuteCommand(rootCmd, cmdConfig, "--default-namespace", "foo")
+	_, err := ExecuteCommand(rootCmd, cmdConfig, "--default-namespace", "foo")
 	require.NoError(t, err)
 	assert.Equal(t, "foo", configCmdOptions.DefaultNamespace)
 }
 
 func TestConfigListFlag(t *testing.T) {
 	_, rootCmd, _ := initializeConfigCmdOptions(t, false)
-	output, err := test.ExecuteCommand(rootCmd, cmdConfig, "--list")
+	output, err := ExecuteCommand(rootCmd, cmdConfig, "--list")
 	require.NoError(t, err)
 	assert.True(t, strings.Contains(output, "No settings"), "The output is unexpected: "+output)
 }
 
 func TestConfigFolderFlagToUsed(t *testing.T) {
 	_, rootCmd, _ := initializeConfigCmdOptions(t, false)
-	output, err := test.ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "used")
+	output, err := ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "used")
 	require.NoError(t, err)
 	assert.True(t, strings.Contains(output, fmt.Sprintf(" %s", DefaultConfigLocation)), "The output is unexpected: "+output)
 }
 
 func TestConfigFolderFlagToSub(t *testing.T) {
 	_, rootCmd, _ := initializeConfigCmdOptions(t, false)
-	output, err := test.ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "sub")
+	output, err := ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "sub")
 	require.NoError(t, err)
 	assert.True(t, strings.Contains(output, filepath.FromSlash(fmt.Sprintf(".kamel/%s", DefaultConfigLocation))), "The output is unexpected: "+output)
 }
 
 func TestConfigFolderFlagToHome(t *testing.T) {
 	_, rootCmd, _ := initializeConfigCmdOptions(t, false)
-	output, err := test.ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "home")
+	output, err := ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "home")
 	require.NoError(t, err)
 	assert.True(t, strings.Contains(output, filepath.FromSlash(fmt.Sprintf(".kamel/%s", DefaultConfigLocation))), "The output is unexpected: "+output)
 }
@@ -101,7 +100,7 @@ func TestConfigFolderFlagToEnv(t *testing.T) {
 	os.Setenv("KAMEL_CONFIG_PATH", "/foo/bar")
 	t.Cleanup(func() { os.Unsetenv("KAMEL_CONFIG_PATH") })
 	_, rootCmd, _ := initializeConfigCmdOptions(t, false)
-	output, err := test.ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "env")
+	output, err := ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "env")
 	require.NoError(t, err)
 	assert.True(t, strings.Contains(output, filepath.FromSlash(fmt.Sprintf("foo/bar/%s", DefaultConfigLocation))), "The output is unexpected: "+output)
 }
@@ -114,7 +113,7 @@ func TestConfigFolderFlagToEnvWithConfigName(t *testing.T) {
 		os.Unsetenv("KAMEL_CONFIG_PATH")
 	})
 	_, rootCmd, _ := initializeConfigCmdOptions(t, false)
-	output, err := test.ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "env")
+	output, err := ExecuteCommand(rootCmd, cmdConfig, "--list", "--folder", "env")
 	require.NoError(t, err)
 	assert.True(t, strings.Contains(output, filepath.FromSlash("/foo/bar/config.yaml")), "The output is unexpected: "+output)
 }
@@ -124,15 +123,15 @@ func TestConfigDefaultNamespace(t *testing.T) {
 	assert.True(t, os.IsNotExist(err), "No file at "+DefaultConfigLocation+" was expected")
 	_, rootCmd, _ := initializeConfigCmdOptions(t, false)
 	t.Cleanup(func() { os.Remove(DefaultConfigLocation) })
-	_, err = test.ExecuteCommand(rootCmd, cmdConfig, "--default-namespace", "foo")
+	_, err = ExecuteCommand(rootCmd, cmdConfig, "--default-namespace", "foo")
 	require.NoError(t, err)
 	_, err = os.Stat(DefaultConfigLocation)
 	require.NoError(t, err, "A file at "+DefaultConfigLocation+" was expected")
-	output, err := test.ExecuteCommand(rootCmd, cmdConfig, "--list")
+	output, err := ExecuteCommand(rootCmd, cmdConfig, "--list")
 	require.NoError(t, err)
 	assert.True(t, strings.Contains(output, "foo"), "The output is unexpected: "+output)
 	_, rootCmd, _ = initializeInstallCmdOptions(t)
-	_, err = test.ExecuteCommand(rootCmd, cmdInstall)
+	_, err = ExecuteCommand(rootCmd, cmdInstall)
 	require.NoError(t, err)
 	// Check default namespace is set
 	assert.Equal(t, "foo", rootCmd.Flag("namespace").Value.String())
