@@ -27,12 +27,12 @@ import (
 	"time"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/internal"
 	"github.com/apache/camel-k/v2/pkg/platform"
 	"github.com/apache/camel-k/v2/pkg/util/boolean"
 	"github.com/apache/camel-k/v2/pkg/util/defaults"
 	"github.com/apache/camel-k/v2/pkg/util/log"
 	"github.com/apache/camel-k/v2/pkg/util/maven"
-	"github.com/apache/camel-k/v2/pkg/util/test"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	corev1 "k8s.io/api/core/v1"
@@ -54,7 +54,7 @@ func TestCreate(t *testing.T) {
 			},
 		},
 	}
-	c, err := test.NewFakeClient(&ip)
+	c, err := internal.NewFakeClient(&ip)
 	require.NoError(t, err)
 
 	h := NewCreateAction()
@@ -98,7 +98,7 @@ func TestCatalogAlreadyPresent(t *testing.T) {
 		"camel.version": "4.4.0",
 	}
 
-	c, err := test.NewFakeClient(&ip, &catalog)
+	c, err := internal.NewFakeClient(&ip, &catalog)
 	require.NoError(t, err)
 
 	action := NewCreateAction()
@@ -136,7 +136,7 @@ func TestCreateNewCatalog(t *testing.T) {
 		maven.DefaultMavenRepositories += ",https://repository.apache.org/content/repositories/snapshots-group@snapshots@id=apache-snapshots"
 	}
 
-	c, err := test.NewFakeClient(&ip)
+	c, err := internal.NewFakeClient(&ip)
 	require.NoError(t, err)
 
 	// use local Maven executable in tests
@@ -146,7 +146,7 @@ func TestCreateNewCatalog(t *testing.T) {
 		t.Setenv("MAVEN_CMD", "mvn")
 	}
 
-	fakeClient := c.(*test.FakeClient) //nolint
+	fakeClient := c.(*internal.FakeClient) //nolint
 	fakeClient.AddReactor("create", "*", func(action k8stesting.Action) (bool, runtime.Object, error) {
 		createAction := action.(k8stesting.CreateAction) //nolint
 
@@ -199,7 +199,7 @@ func TestCreateNewCatalog(t *testing.T) {
 		},
 	}
 	// Refresh client with changed IP
-	c, err = test.NewFakeClient(&ip)
+	c, err = internal.NewFakeClient(&ip)
 	require.NoError(t, err)
 	action.InjectClient(c)
 	answer, err = action.Handle(context.TODO(), &ip)
@@ -216,7 +216,7 @@ func TestCreateCatalogError(t *testing.T) {
 	ip.Namespace = "ns"
 	ip.Name = "ck"
 	ip.Spec.Build.RuntimeVersion = "0.0.0"
-	c, err := test.NewFakeClient(&ip)
+	c, err := internal.NewFakeClient(&ip)
 	require.NoError(t, err)
 
 	// use local Maven executable in tests
@@ -226,7 +226,7 @@ func TestCreateCatalogError(t *testing.T) {
 		t.Setenv("MAVEN_CMD", "mvn")
 	}
 
-	fakeClient := c.(*test.FakeClient) //nolint
+	fakeClient := c.(*internal.FakeClient) //nolint
 	fakeClient.AddReactor("create", "*", func(action k8stesting.Action) (bool, runtime.Object, error) {
 		createAction := action.(k8stesting.CreateAction) //nolint
 
