@@ -50,8 +50,8 @@ const (
 	kamelVersionAnnotation = "camel.apache.org/version"
 )
 
-// installKameletCatalog installs the version Apache Kamelet Catalog into the specified namespace. It returns the number of Kamelets installed and errored
-// if successful.
+// installKameletCatalog installs the version Apache Kamelet Catalog into the specified namespace.
+// It returns the number of Kamelets installed and errored if successful.
 func installKameletCatalog(ctx context.Context, c client.Client, platform *v1.IntegrationPlatform, version string) (int, int, error) {
 	// Prepare proper privileges for Kamelets installed globally
 	if err := prepareKameletsPermissions(ctx, c, platform.Namespace); err != nil {
@@ -105,6 +105,8 @@ func prepareKameletDirectory() (string, error) {
 func downloadKameletDependency(ctx context.Context, c client.Client, platform *v1.IntegrationPlatform, version, kameletsDir string) error {
 	p := maven.NewProjectWithGAV("org.apache.camel.k.kamelets", "kamelets-catalog", defaults.Version)
 	mc := maven.NewContext(kameletsDir)
+	mc.LocalRepository = platform.Status.Build.Maven.LocalRepository
+	mc.AdditionalArguments = platform.Status.Build.Maven.CLIOptions
 	mc.AddArgument("-q")
 	mc.AddArgument("dependency:copy")
 	mc.AddArgument(fmt.Sprintf("-Dartifact=org.apache.camel.kamelets:camel-kamelets:%s:jar", version))
