@@ -24,9 +24,9 @@ import (
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+	"github.com/apache/camel-k/v2/pkg/internal"
 	"github.com/apache/camel-k/v2/pkg/util/defaults"
 	"github.com/apache/camel-k/v2/pkg/util/log"
-	"github.com/apache/camel-k/v2/pkg/util/test"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
@@ -38,7 +38,7 @@ func TestCanHandlePhaseReadyOrError(t *testing.T) {
 	ip.Namespace = "ns"
 	ip.Name = "ck"
 	ip.Status.Phase = v1.IntegrationPlatformPhaseReady
-	c, err := test.NewFakeClient(&ip)
+	c, err := internal.NewFakeClient(&ip)
 	require.NoError(t, err)
 
 	action := NewMonitorAction()
@@ -74,7 +74,7 @@ func TestMonitorReady(t *testing.T) {
 	ip.Status.Build.RuntimeProvider = v1.RuntimeProviderQuarkus
 	ip.Status.Build.Registry.Address = "1.2.3.4"
 	ip.Status.Phase = v1.IntegrationPlatformPhaseReady
-	c, err := test.NewFakeClient(&ip, &catalog)
+	c, err := internal.NewFakeClient(&ip, &catalog)
 	require.NoError(t, err)
 
 	action := NewMonitorAction()
@@ -87,6 +87,7 @@ func TestMonitorReady(t *testing.T) {
 
 	assert.Equal(t, v1.IntegrationPlatformPhaseReady, answer.Status.Phase)
 	assert.Equal(t, corev1.ConditionTrue, answer.Status.GetCondition(v1.IntegrationPlatformConditionTypeRegistryAvailable).Status)
+	assert.Nil(t, answer.Status.GetCondition(v1.IntegrationPlatformConditionType("InsecureRegistryWarning")))
 	assert.Equal(t, "3.2.1", answer.Status.Build.RuntimeCoreVersion)
 }
 
@@ -100,7 +101,7 @@ func TestMonitorDriftRuntime(t *testing.T) {
 	ip.Status.Build.RuntimeProvider = v1.RuntimeProviderQuarkus
 	ip.Status.Build.Registry.Address = "1.2.3.4"
 	ip.Status.Phase = v1.IntegrationPlatformPhaseReady
-	c, err := test.NewFakeClient(&ip)
+	c, err := internal.NewFakeClient(&ip)
 	require.NoError(t, err)
 
 	action := NewMonitorAction()
@@ -129,7 +130,7 @@ func TestMonitorDriftDefault(t *testing.T) {
 	ip.Status.Build.RuntimeProvider = v1.RuntimeProviderQuarkus
 	ip.Status.Build.Registry.Address = "1.2.3.4"
 	ip.Status.Phase = v1.IntegrationPlatformPhaseReady
-	c, err := test.NewFakeClient(&ip, &catalog)
+	c, err := internal.NewFakeClient(&ip, &catalog)
 	require.NoError(t, err)
 
 	action := NewMonitorAction()
@@ -181,7 +182,7 @@ func TestMonitorDriftConfiguration(t *testing.T) {
 	}
 	ip.Namespace = "ns"
 	ip.Name = "ck"
-	c, err := test.NewFakeClient(&ip, &catalog)
+	c, err := internal.NewFakeClient(&ip, &catalog)
 	require.NoError(t, err)
 
 	action := NewMonitorAction()
@@ -213,7 +214,7 @@ func TestMonitorMissingRegistryError(t *testing.T) {
 	ip.Spec.Build.RuntimeProvider = v1.RuntimeProviderQuarkus
 	ip.Status.Build.RuntimeVersion = "1.2.3"
 	ip.Status.Build.RuntimeProvider = v1.RuntimeProviderQuarkus
-	c, err := test.NewFakeClient(&ip, &catalog)
+	c, err := internal.NewFakeClient(&ip, &catalog)
 	require.NoError(t, err)
 
 	action := NewMonitorAction()
@@ -236,7 +237,7 @@ func TestMonitorMissingCatalogError(t *testing.T) {
 	ip.Name = "ck"
 	ip.Status.Build.RuntimeVersion = defaults.DefaultRuntimeVersion
 	ip.Status.Build.RuntimeProvider = v1.RuntimeProviderQuarkus
-	c, err := test.NewFakeClient(&ip)
+	c, err := internal.NewFakeClient(&ip)
 	require.NoError(t, err)
 
 	action := NewMonitorAction()
@@ -255,3 +256,41 @@ func TestMonitorMissingCatalogError(t *testing.T) {
 		defaults.DefaultRuntimeVersion), answer.Status.GetCondition(
 		v1.IntegrationPlatformConditionCamelCatalogAvailable).Message)
 }
+
+func TestMonitorWarningInsecureRegistry(t *testing.T) {
+	catalog := v1.NewCamelCatalog("ns", fmt.Sprintf("camel-catalog-%s", "1.2.3"))
+	catalog.Spec.Runtime.Version = "1.2.3"
+	catalog.Spec.Runtime.Provider = v1.RuntimeProviderQuarkus
+	catalog.Spec.Runtime.Metadata = map[string]string{
+		"camel.version": "3.2.1",
+	}
+	ip := v1.IntegrationPlatform{}
+	ip.Namespace = "ns"
+	ip.Name = "ck"
+	ip.Spec.Build.Registry.Address = "1.2.3.4"
+	ip.Spec.Build.Registry.Insecure = true
+	ip.Spec.Build.RuntimeVersion = "1.2.3"
+	ip.Spec.Build.RuntimeProvider = v1.RuntimeProviderQuarkus
+	ip.Status.Build.RuntimeVersion = "1.2.3"
+	ip.Status.Build.RuntimeProvider = v1.RuntimeProviderQuarkus
+	ip.Status.Build.Registry.Address = "1.2.3.4"
+	ip.Status.Build.Registry.Insecure = true
+	ip.Status.Phase = v1.IntegrationPlatformPhaseReady
+	c, err := internal.NewFakeClient(&ip, &catalog)
+	require.NoError(t, err)
+
+	action := NewMonitorAction()
+	action.InjectLogger(log.Log)
+	action.InjectClient(c)
+
+	answer, err := action.Handle(context.TODO(), &ip)
+	require.NoError(t, err)
+	assert.NotNil(t, answer)
+
+	assert.Equal(t, v1.IntegrationPlatformPhaseReady, answer.Status.Phase)
+	assert.Equal(t, corev1.ConditionTrue, answer.Status.GetCondition(v1.IntegrationPlatformConditionTypeRegistryAvailable).Status)
+	assert.Equal(t, corev1.ConditionTrue, answer.Status.GetCondition(v1.IntegrationPlatformConditionType("InsecureRegistryWarning")).Status)
+	assert.Equal(t, "Registry is insecure. This setup should not be used in a production environment.",
+		answer.Status.GetCondition(
+			v1.IntegrationPlatformConditionType("InsecureRegistryWarning")).Message)
+}
