@@ -74,29 +74,24 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	}
 
 	// Watch for changes to primary resource IntegrationProfile
-	err = c.Watch(source.Kind(mgr.GetCache(), &v1.IntegrationProfile{}),
-		&handler.EnqueueRequestForObject{},
-		platform.FilteringFuncs{
-			UpdateFunc: func(e event.UpdateEvent) bool {
-				oldIntegrationProfile, ok := e.ObjectOld.(*v1.IntegrationProfile)
-				if !ok {
-					return false
-				}
-				newIntegrationProfile, ok := e.ObjectNew.(*v1.IntegrationProfile)
-				if !ok {
-					return false
-				}
-				// Ignore updates to the integration profile status in which case metadata.Generation
-				// does not change, or except when the integration profile phase changes as it's used
-				// to transition from one phase to another
-				return oldIntegrationProfile.Generation != newIntegrationProfile.Generation ||
-					oldIntegrationProfile.Status.Phase != newIntegrationProfile.Status.Phase
+	err = c.Watch(
+		source.Kind(mgr.GetCache(),
+			&v1.IntegrationProfile{},
+			&handler.TypedEnqueueRequestForObject[*v1.IntegrationProfile]{},
+			platform.FilteringFuncs[*v1.IntegrationProfile]{
+				UpdateFunc: func(e event.TypedUpdateEvent[*v1.IntegrationProfile]) bool {
+					// Ignore updates to the integration profile status in which case metadata.Generation
+					// does not change, or except when the integration profile phase changes as it's used
+					// to transition from one phase to another
+					return e.ObjectOld.Generation != e.ObjectNew.Generation ||
+						e.ObjectOld.Status.Phase != e.ObjectNew.Status.Phase
+				},
+				DeleteFunc: func(e event.TypedDeleteEvent[*v1.IntegrationProfile]) bool {
+					// Evaluates to false if the object has been confirmed deleted
+					return !e.DeleteStateUnknown
+				},
 			},
-			DeleteFunc: func(e event.DeleteEvent) bool {
-				// Evaluates to false if the object has been confirmed deleted
-				return !e.DeleteStateUnknown
-			},
-		},
+		),
 	)
 	if err != nil {
 		return err
