@@ -383,13 +383,14 @@ func (t *quarkusTrait) applyWhenBuildSubmitted(e *Environment) error {
 
 	//nolint:nestif
 	if native {
+		buildTask.Maven.Properties["quarkus.native.enabled"] = "true"
 		if nativePackageType := builder.QuarkusRuntimeSupport(e.CamelCatalog.GetCamelQuarkusVersion()).NativeMavenProperty(); nativePackageType != "" {
-			buildTask.Maven.Properties["quarkus.package.type"] = nativePackageType
-			if t.NativeBaseImage == "" {
-				packageTask.BaseImage = QuarkusNativeDefaultBaseImageName
-			} else {
-				packageTask.BaseImage = t.NativeBaseImage
-			}
+			buildTask.Maven.Properties[nativePackageType] = "true"
+		}
+		if t.NativeBaseImage == "" {
+			packageTask.BaseImage = QuarkusNativeDefaultBaseImageName
+		} else {
+			packageTask.BaseImage = t.NativeBaseImage
 		}
 		if len(e.IntegrationKit.Spec.Sources) > 0 {
 			buildTask.Sources = e.IntegrationKit.Spec.Sources
@@ -400,7 +401,7 @@ func (t *quarkusTrait) applyWhenBuildSubmitted(e *Environment) error {
 		packageSteps = append(packageSteps, builder.Image.ExecutableDockerfile)
 	} else {
 		// Default, if nothing is specified
-		buildTask.Maven.Properties["quarkus.package.type"] = string(fastJarPackageType)
+		buildTask.Maven.Properties["quarkus.package.jar.type"] = string(fastJarPackageType)
 		packageSteps = append(packageSteps, builder.Quarkus.ComputeQuarkusDependencies)
 		if t.isIncrementalImageBuild(e) {
 			packageSteps = append(packageSteps, builder.Image.IncrementalImageContext)
