@@ -29,7 +29,6 @@ func init() {
 	AddToTraits(newDeployerTrait)
 	AddToTraits(newDeploymentTrait)
 	AddToTraits(newEnvironmentTrait)
-	AddToTraits(newErrorHandlerTrait)
 	AddToTraits(newGCTrait)
 	AddToTraits(newHealthTrait)
 	AddToTraits(NewInitTrait)
@@ -41,6 +40,7 @@ func init() {
 	AddToTraits(newKnativeTrait)
 	AddToTraits(newKnativeServiceTrait)
 	AddToTraits(newLoggingTraitTrait)
+	AddToTraits(NewMasterTrait)
 	AddToTraits(newMountTrait)
 	AddToTraits(newOpenAPITrait)
 	AddToTraits(newOwnerTrait)
