@@ -25,8 +25,8 @@ import (
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/v2/pkg/util/test"
 
+	"github.com/apache/camel-k/v2/pkg/internal"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -49,7 +49,7 @@ func TestToTraitMap(t *testing.T) {
 			},
 		},
 		Addons: map[string]v1.AddonTrait{
-			"telemetry": ToAddonTrait(t, map[string]interface{}{
+			"telemetry": toAddonTrait(t, map[string]interface{}{
 				"enabled": true,
 			}),
 		},
@@ -80,33 +80,6 @@ func TestToTraitMap(t *testing.T) {
 	assert.Equal(t, expected, traitMap)
 }
 
-func TestToPropertyMap(t *testing.T) {
-	trait := traitv1.ContainerTrait{
-		PlatformBaseTrait: traitv1.PlatformBaseTrait{},
-		Name:              "test-container",
-		Auto:              ptr.To(false),
-		Expose:            ptr.To(true),
-		Port:              8081,
-		PortName:          "http-8081",
-		ServicePort:       81,
-		ServicePortName:   "http-81",
-	}
-	expected := map[string]interface{}{
-		"auto":            false,
-		"expose":          true,
-		"port":            float64(8081),
-		"portName":        "http-8081",
-		"servicePort":     float64(81),
-		"servicePortName": "http-81",
-		"name":            "test-container",
-	}
-
-	propMap, err := ToPropertyMap(trait)
-
-	require.NoError(t, err)
-	assert.Equal(t, expected, propMap)
-}
-
 func TestMigrateLegacyConfiguration(t *testing.T) {
 	trait := map[string]interface{}{
 		"enabled":         true,
@@ -175,111 +148,8 @@ func TestToTrait(t *testing.T) {
 }
 
 func TestSameTraits(t *testing.T) {
-	c, err := test.NewFakeClient()
+	c, err := internal.NewFakeClient()
 	require.NoError(t, err)
-	t.Run("empty traits", func(t *testing.T) {
-		oldKlb := &v1.Pipe{
-			Spec: v1.PipeSpec{
-				Integration: &v1.IntegrationSpec{
-					Traits: v1.Traits{},
-				},
-			},
-		}
-		newKlb := &v1.Pipe{
-			Spec: v1.PipeSpec{
-				Integration: &v1.IntegrationSpec{
-					Traits: v1.Traits{},
-				},
-			},
-		}
-
-		ok, err := PipesHaveSameTraits(c, oldKlb, newKlb)
-		require.NoError(t, err)
-		assert.True(t, ok)
-	})
-
-	t.Run("same traits", func(t *testing.T) {
-		oldKlb := &v1.Pipe{
-			Spec: v1.PipeSpec{
-				Integration: &v1.IntegrationSpec{
-					Traits: v1.Traits{
-						Container: &traitv1.ContainerTrait{
-							Image: "foo/bar:1",
-						},
-					},
-				},
-			},
-		}
-		newKlb := &v1.Pipe{
-			Spec: v1.PipeSpec{
-				Integration: &v1.IntegrationSpec{
-					Traits: v1.Traits{
-						Container: &traitv1.ContainerTrait{
-							Image: "foo/bar:1",
-						},
-					},
-				},
-			},
-		}
-
-		ok, err := PipesHaveSameTraits(c, oldKlb, newKlb)
-		require.NoError(t, err)
-		assert.True(t, ok)
-	})
-
-	t.Run("not same traits", func(t *testing.T) {
-		oldKlb := &v1.Pipe{
-			Spec: v1.PipeSpec{
-				Integration: &v1.IntegrationSpec{
-					Traits: v1.Traits{
-						Container: &traitv1.ContainerTrait{
-							Image: "foo/bar:1",
-						},
-					},
-				},
-			},
-		}
-		newKlb := &v1.Pipe{
-			Spec: v1.PipeSpec{
-				Integration: &v1.IntegrationSpec{
-					Traits: v1.Traits{
-						Owner: &traitv1.OwnerTrait{
-							TargetAnnotations: []string{"foo"},
-						},
-					},
-				},
-			},
-		}
-
-		ok, err := PipesHaveSameTraits(c, oldKlb, newKlb)
-		require.NoError(t, err)
-		assert.False(t, ok)
-	})
-
-	t.Run("same traits with annotations", func(t *testing.T) {
-		oldKlb := &v1.Pipe{
-			Spec: v1.PipeSpec{
-				Integration: &v1.IntegrationSpec{
-					Traits: v1.Traits{
-						Container: &traitv1.ContainerTrait{
-							Image: "foo/bar:1",
-						},
-					},
-				},
-			},
-		}
-		newKlb := &v1.Pipe{
-			ObjectMeta: metav1.ObjectMeta{
-				Annotations: map[string]string{
-					v1.TraitAnnotationPrefix + "container.image": "foo/bar:1",
-				},
-			},
-		}
-
-		ok, err := PipesHaveSameTraits(c, oldKlb, newKlb)
-		require.NoError(t, err)
-		assert.True(t, ok)
-	})
 
 	t.Run("same traits with annotations only", func(t *testing.T) {
 		oldKlb := &v1.Pipe{
@@ -302,31 +172,6 @@ func TestSameTraits(t *testing.T) {
 		assert.True(t, ok)
 	})
 
-	t.Run("not same traits with annotations", func(t *testing.T) {
-		oldKlb := &v1.Pipe{
-			Spec: v1.PipeSpec{
-				Integration: &v1.IntegrationSpec{
-					Traits: v1.Traits{
-						Container: &traitv1.ContainerTrait{
-							Image: "foo/bar:1",
-						},
-					},
-				},
-			},
-		}
-		newKlb := &v1.Pipe{
-			ObjectMeta: metav1.ObjectMeta{
-				Annotations: map[string]string{
-					v1.TraitAnnotationPrefix + "container.image": "foo/bar:2",
-				},
-			},
-		}
-
-		ok, err := PipesHaveSameTraits(c, oldKlb, newKlb)
-		require.NoError(t, err)
-		assert.False(t, ok)
-	})
-
 	t.Run("not same traits with annotations only", func(t *testing.T) {
 		oldKlb := &v1.Pipe{
 			ObjectMeta: metav1.ObjectMeta{
@@ -413,7 +258,7 @@ func TestIntegrationAndPipeSameTraits(t *testing.T) {
 			},
 		},
 	}
-	c, err := test.NewFakeClient(pipe, integration)
+	c, err := internal.NewFakeClient(pipe, integration)
 	require.NoError(t, err)
 
 	result, err := IntegrationAndPipeSameTraits(c, integration, pipe)
