@@ -125,38 +125,6 @@ func NewResourceRequirements(reqs []string) (corev1.ResourceRequirements, error)
 	return resReq, nil
 }
 
-// NewConfigMap will create a ConfigMap.
-func NewConfigMap(namespace, cmName, originalFilename string, generatedKey string,
-	textData string, binaryData []byte) *corev1.ConfigMap {
-	immutable := true
-	cm := corev1.ConfigMap{
-		TypeMeta: metav1.TypeMeta{
-			Kind:       "ConfigMap",
-			APIVersion: "v1",
-		},
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      cmName,
-			Namespace: namespace,
-			Labels: map[string]string{
-				ConfigMapOriginalFileNameLabel: originalFilename,
-				ConfigMapAutogenLabel:          "true",
-			},
-		},
-		Immutable: &immutable,
-	}
-	if textData != "" {
-		cm.Data = map[string]string{
-			generatedKey: textData,
-		}
-	}
-	if binaryData != nil {
-		cm.BinaryData = map[string][]byte{
-			generatedKey: binaryData,
-		}
-	}
-	return &cm
-}
-
 // NewPersistentVolumeClaim will create a NewPersistentVolumeClaim based on a StorageClass.
 func NewPersistentVolumeClaim(
 	ns, name, storageClassName string, capacityStorage resource.Quantity, accessMode corev1.PersistentVolumeAccessMode) *corev1.PersistentVolumeClaim {
