@@ -21,17 +21,18 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestParseGroovyFile(t *testing.T) {
 	it := `
-		//     camel-k: pippo=pluto     paperino ciao=1   
+		//     camel-k: pippo=pluto     paperino ciao=1
 		// camel-k : ciao
 
 		from("timer:tick").log("Ciao")
     `
 	opts, err := Parse("simple.groovy", it)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Len(t, opts, 4)
 	assert.Contains(t, opts, Option{Name: "pippo", Value: "pluto"})
 	assert.Contains(t, opts, Option{Name: "paperino"})
@@ -41,13 +42,13 @@ func TestParseGroovyFile(t *testing.T) {
 
 func TestParseKotlinFile(t *testing.T) {
 	it := `
-		//     camel-k: pippo=pluto     paperino ciao=1   
+		//     camel-k: pippo=pluto     paperino ciao=1
 		// camel-k : ciao
 
 		from("timer:tick").log("Ciao")
     `
 	opts, err := Parse("example.kts", it)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Len(t, opts, 4)
 	assert.Contains(t, opts, Option{Name: "pippo", Value: "pluto"})
 	assert.Contains(t, opts, Option{Name: "paperino"})
@@ -57,27 +58,27 @@ func TestParseKotlinFile(t *testing.T) {
 
 func TestParseJavaFile(t *testing.T) {
 	it := `
-		//     camel-k: pippo=pluto     paperino ciao=1   
+		//     camel-k: pippo=pluto     paperino ciao=1
 		// camel-k : ciao
 
 		import org.apache.camel.builder.RouteBuilder;
-		
+
 		public class {{ .Name }} extends RouteBuilder {
 		  @Override
 		  public void configure() throws Exception {
-		
+
 			  // Write your routes here, for example:
 			  from("timer:java?period=1000")
 				.routeId("java")
 				.setBody()
 				  .simple("Hello Camel K from ${routeId}")
 				.to("log:info");
-		
+
 		  }
 		}
     `
 	opts, err := Parse("Example.java", it)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Len(t, opts, 4)
 	assert.Contains(t, opts, Option{Name: "pippo", Value: "pluto"})
 	assert.Contains(t, opts, Option{Name: "paperino"})
@@ -87,8 +88,8 @@ func TestParseJavaFile(t *testing.T) {
 
 func TestParseJSFile(t *testing.T) {
 	it := `
-		//     camel-k: pippo=pluto     paperino ciao=1   
-		// camel-k : ciao 
+		//     camel-k: pippo=pluto     paperino ciao=1
+		// camel-k : ciao
 		// Write your routes here, for example:
 		from('timer:js?period=1000')
 			.routeId('js')
@@ -97,7 +98,7 @@ func TestParseJSFile(t *testing.T) {
 			.to('log:info')
     `
 	opts, err := Parse("example.js", it)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Len(t, opts, 4)
 	assert.Contains(t, opts, Option{Name: "pippo", Value: "pluto"})
 	assert.Contains(t, opts, Option{Name: "paperino"})
@@ -107,8 +108,8 @@ func TestParseJSFile(t *testing.T) {
 
 func TestParseYAMLFile(t *testing.T) {
 	it := `
-		#     camel-k: pippo=pluto     paperino ciao=1   
-		### camel-k : ciao 
+		#     camel-k: pippo=pluto     paperino ciao=1
+		### camel-k : ciao
 
 		# Write your routes here, for example:
 		- from:
@@ -116,13 +117,13 @@ func TestParseYAMLFile(t *testing.T) {
 			parameters:
 			  period: "1000"
 			steps:
-			  - set-body:
+			  - setBody:
 				  constant: "Hello Camel K from yaml"
 			  - to: "log:info"
 
     `
 	opts, err := Parse("example.yaml", it)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Len(t, opts, 4)
 	assert.Contains(t, opts, Option{Name: "pippo", Value: "pluto"})
 	assert.Contains(t, opts, Option{Name: "paperino"})
@@ -132,8 +133,8 @@ func TestParseYAMLFile(t *testing.T) {
 
 func TestParseXMLFile(t *testing.T) {
 	it := `
-		#     camel-k: pippo=pluto     paperino ciao=1   
-		### camel-k : ciao 
+		#     camel-k: pippo=pluto     paperino ciao=1
+		### camel-k : ciao
 
 		<?xml version="1.0" encoding="UTF-8"?>
 		<!--     camel-k: pippo=pluto     paperino ciao=1-->
@@ -145,7 +146,7 @@ func TestParseXMLFile(t *testing.T) {
 				xsi:schemaLocation="
 					http://camel.apache.org/schema/spring
 					https://camel.apache.org/schema/spring/camel-spring.xsd">
-		
+
 			<!-- Write your routes here, for example: -->
 			<route id="xml">
 				<from uri="timer:xml?period=1000"/>
@@ -154,13 +155,13 @@ func TestParseXMLFile(t *testing.T) {
 				</setBody>
 				<to uri="log:info"/>
 			</route>
-		
+
 		</routes>
 
 
     `
 	opts, err := Parse("example.xml", it)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Len(t, opts, 5)
 	assert.Contains(t, opts, Option{Name: "pippo", Value: "pluto"})
 	assert.Contains(t, opts, Option{Name: "paperino"})
