@@ -88,6 +88,10 @@ func (i YAMLInspector) parseDefinition(def map[string]interface{}, meta *Metadat
 //nolint:nestif
 func (i YAMLInspector) parseStep(key string, content interface{}, meta *Metadata) error {
 	switch key {
+	case "bean":
+		if bean := i.catalog.GetArtifactByScheme("bean"); bean != nil {
+			meta.AddDependency(bean.GetDependencyID())
+		}
 	case "rest":
 		meta.ExposesHTTPServices = true
 		meta.RequiredCapabilities.Add(v1.CapabilityRest)
@@ -107,13 +111,13 @@ func (i YAMLInspector) parseStep(key string, content interface{}, meta *Metadata
 				}
 			}
 		}
-	case "kamelet":
+	case kamelet:
 		switch t := content.(type) {
 		case string:
-			AddKamelet(meta, "kamelet:"+t)
+			AddKamelet(meta, kamelet+":"+t)
 		case map[interface{}]interface{}:
 			if name, ok := t["name"].(string); ok {
-				AddKamelet(meta, "kamelet:"+name)
+				AddKamelet(meta, kamelet+":"+name)
 			}
 		}
 	}
@@ -166,6 +170,16 @@ func (i YAMLInspector) parseStep(key string, content interface{}, meta *Metadata
 						return err
 					}
 				}
+			case "deadLetterUri":
+				if s, ok := v.(string); ok {
+					_, scheme := i.catalog.DecodeComponent(s)
+					if dfDep := i.catalog.GetArtifactByScheme(scheme.ID); dfDep != nil {
+						meta.AddDependency(dfDep.GetDependencyID())
+					}
+					if scheme.ID == kamelet {
+						AddKamelet(meta, s)
+					}
+				}
 			default:
 				// Always follow children because from/to uris can be nested
 				if ks, ok := k.(string); ok {
