@@ -757,3 +757,76 @@ func TestYAMLRESTContractFirst(t *testing.T) {
 		})
 	})
 }
+
+const yamlBean = `
+- from:
+    uri: "timer:foo"
+    steps:
+    - bean:
+        type: "#xyz"
+    - to: "log:bar"
+`
+
+func TestYamlBeanDependencies(t *testing.T) {
+	inspector := newTestYAMLInspector(t)
+
+	assertExtract(t, inspector, yamlBean, func(meta *Metadata) {
+		assert.Contains(t, meta.Dependencies.List(), "camel:timer")
+		assert.Contains(t, meta.Dependencies.List(), "camel:bean")
+		assert.Contains(t, meta.Dependencies.List(), "camel:log")
+	})
+}
+
+func TestYAMLErrorHandler(t *testing.T) {
+	yamlContractFirst := `
+- errorHandler:
+    deadLetterChannel:
+      deadLetterUri: kafka:my-dlc
+- route:
+    id: route1
+    from:
+      uri: "timer:tick"
+      parameters:
+        period: "5000"
+    steps:
+      - setBody:
+          constant: "Hello Yaml !!!"
+      - transform:
+          simple: "${body.toUpperCase()}"
+      - to: "{{url}}"
+`
+
+	inspector := newTestYAMLInspector(t)
+	t.Run("TestYAMLErrorHandler", func(t *testing.T) {
+		assertExtractYAML(t, inspector, yamlContractFirst, func(meta *Metadata) {
+			assert.Contains(t, meta.Dependencies.List(), "camel:kafka")
+		})
+	})
+}
+
+func TestYAMLErrorHandlerKamelet(t *testing.T) {
+	yamlContractFirst := `
+- errorHandler:
+    deadLetterChannel:
+      deadLetterUri: kamelet:my-kamelet/errorHandler
+- route:
+    id: route1
+    from:
+      uri: "timer:tick"
+      parameters:
+        period: "5000"
+    steps:
+      - setBody:
+          constant: "Hello Yaml !!!"
+      - transform:
+          simple: "${body.toUpperCase()}"
+      - to: "{{url}}"
+`
+
+	inspector := newTestYAMLInspector(t)
+	t.Run("TestYAMLErrorHandler", func(t *testing.T) {
+		assertExtractYAML(t, inspector, yamlContractFirst, func(meta *Metadata) {
+			assert.Contains(t, meta.Kamelets, "my-kamelet/error")
+		})
+	})
+}
