@@ -24,7 +24,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/fs"
+	"math"
 	"math/rand"
 	"os"
 	"path"
@@ -43,63 +43,12 @@ import (
 	yaml2 "gopkg.in/yaml.v2"
 )
 
-// Directories and file names:
-
-// DefaultDependenciesDirectoryName --.
-const DefaultDependenciesDirectoryName = "dependencies"
-
-// DefaultPropertiesDirectoryName --.
-const DefaultPropertiesDirectoryName = "properties"
-
-// DefaultRoutesDirectoryName --.
-const DefaultRoutesDirectoryName = "routes"
-
-// DefaultWorkingDirectoryName --.
-const DefaultWorkingDirectoryName = "workspace"
-
-// CustomQuarkusDirectoryName --.
-const CustomQuarkusDirectoryName = "quarkus"
-
-// CustomAppDirectoryName --.
-const CustomAppDirectoryName = "app"
-
-// CustomLibDirectoryName --.
-const CustomLibDirectoryName = "lib/main"
-
-// ContainerDependenciesDirectory --.
-var ContainerDependenciesDirectory = "/deployments/dependencies"
-
-// ContainerPropertiesDirectory --.
-var ContainerPropertiesDirectory = "/etc/camel/conf.d"
-
-// ContainerRoutesDirectory --.
-var ContainerRoutesDirectory = "/etc/camel/sources"
-
-// ContainerResourcesDirectory --.
-var ContainerResourcesDirectory = "/etc/camel/resources.d"
-
-// ContainerQuarkusDirectoryName --.
-const ContainerQuarkusDirectoryName = "/quarkus"
-
-// ContainerAppDirectoryName --.
-const ContainerAppDirectoryName = "/app"
-
-// ContainerLibDirectoryName --.
-const ContainerLibDirectoryName = "/lib/main"
-
-// QuarkusDependenciesBaseDirectory --.
-var QuarkusDependenciesBaseDirectory = "/quarkus-app"
-
 // ListOfLazyEvaluatedEnvVars -- List of unevaluated environment variables.
 // These are sensitive values or values that may have different values depending on
 // where the integration is run (locally vs. the cloud). These environment variables
 // are evaluated at the time of the integration invocation.
 var ListOfLazyEvaluatedEnvVars []string
 
-// CLIEnvVars -- List of CLI provided environment variables. They take precedence over
-// any environment variables with the same name.
-var CLIEnvVars = make([]string, 0)
-
 func StringSliceJoin(slices ...[]string) []string {
 	size := 0
 
@@ -117,7 +66,7 @@ func StringSliceJoin(slices ...[]string) []string {
 }
 
 func StringSliceContains(slice []string, items []string) bool {
-	for i := range len(items) {
+	for i := range items {
 		if !StringSliceExists(slice, items[i]) {
 			return false
 		}
@@ -127,7 +76,7 @@ func StringSliceContains(slice []string, items []string) bool {
 }
 
 func StringSliceExists(slice []string, item string) bool {
-	for i := range len(slice) {
+	for i := range slice {
 		if slice[i] == item {
 			return true
 		}
@@ -136,19 +85,9 @@ func StringSliceExists(slice []string, item string) bool {
 	return false
 }
 
-func StringContainsPrefix(slice []string, prefix string) bool {
-	for i := range len(slice) {
-		if strings.HasPrefix(slice[i], prefix) {
-			return true
-		}
-	}
-
-	return false
-}
-
 func StringSliceContainsAnyOf(slice []string, items ...string) bool {
-	for i := range len(slice) {
-		for j := range len(items) {
+	for i := range slice {
+		for j := range items {
 			if strings.Contains(slice[i], items[j]) {
 				return true
 			}
@@ -187,15 +126,6 @@ func StringSliceUniqueConcat(slice *[]string, items []string) bool {
 	return changed
 }
 
-func SubstringFrom(s string, substr string) string {
-	index := strings.Index(s, substr)
-	if index != -1 {
-		return s[index:]
-	}
-
-	return ""
-}
-
 func SubstringBefore(s string, substr string) string {
 	index := strings.LastIndex(s, substr)
 	if index != -1 {
@@ -214,7 +144,6 @@ const (
 )
 
 var randomSource = rand.NewSource(time.Now().UnixNano())
-var randomSourceUTC = rand.NewSource(time.Now().UTC().UnixNano())
 
 func RandomString(n int) string {
 	sb := strings.Builder{}
@@ -234,10 +163,6 @@ func RandomString(n int) string {
 	return sb.String()
 }
 
-func RandomInt63() int64 {
-	return randomSourceUTC.Int63()
-}
-
 func EncodeXMLWithoutHeader(content interface{}) ([]byte, error) {
 	return encodeXML(content, "")
 }
@@ -268,8 +193,7 @@ func CopyFile(src, dst string) (int64, error) {
 	}
 
 	if !stat.Mode().IsRegular() {
-		err = fmt.Errorf("%s is not a regular file", src)
-		return 0, err
+		return 0, fmt.Errorf("%s is not a regular file", src)
 	}
 
 	source, err := Open(src)
@@ -303,42 +227,6 @@ func CopyFile(src, dst string) (int64, error) {
 	return nBytes, err
 }
 
-func CopyDir(src, dst string) error {
-	entries, err := os.ReadDir(src)
-	if err != nil {
-		return err
-	}
-
-	for _, entry := range entries {
-		srcEntry := filepath.Join(src, entry.Name())
-		dstEntry := filepath.Join(dst, entry.Name())
-		realEntry := entry
-		if entry.Type() == os.ModeSymlink {
-			realPath, err := filepath.EvalSymlinks(srcEntry)
-			if err != nil {
-				return err
-			}
-			realInfo, err := os.Stat(realPath)
-			if err != nil {
-				return err
-			}
-			srcEntry = realPath
-			realEntry = fs.FileInfoToDirEntry(realInfo)
-		}
-		if realEntry.IsDir() {
-			if err := CopyDir(srcEntry, dstEntry); err != nil {
-				return err
-			}
-		} else {
-			if _, err := CopyFile(srcEntry, dstEntry); err != nil {
-				return err
-			}
-		}
-	}
-
-	return nil
-}
-
 func WriteFileWithBytesMarshallerContent(basePath string, filePath string, content BytesMarshaller) error {
 	data, err := content.MarshalBytes()
 	if err != nil {
@@ -415,27 +303,6 @@ func DirectoryEmpty(directory string) (bool, error) {
 	return ok, err
 }
 
-// CreateDirectory creates a directory if it does not exist.
-func CreateDirectory(directory string) error {
-	if directory == "" {
-		return errors.New("directory name must not be empty")
-	}
-
-	directoryExists, err := DirectoryExists(directory)
-	if err != nil {
-		return err
-	}
-
-	if !directoryExists {
-		// #nosec G301
-		if err := os.MkdirAll(directory, io2.FilePerm755); err != nil {
-			return err
-		}
-	}
-
-	return nil
-}
-
 type BytesMarshaller interface {
 	MarshalBytes() ([]byte, error)
 }
@@ -524,45 +391,6 @@ func GetEnvironmentVariable(variable string) (string, error) {
 	return value, nil
 }
 
-// EvaluateCLIAndLazyEnvVars creates a list of environment
-// variables with entries VAR=value that can be passed when running the integration.
-func EvaluateCLIAndLazyEnvVars() ([]string, error) {
-	evaluatedEnvVars := []string{}
-
-	// Add CLI environment variables
-	setEnvVars := []string{}
-	for _, cliEnvVar := range CLIEnvVars {
-		// Mark variable name as set.
-		varAndValue := strings.Split(cliEnvVar, "=")
-		setEnvVars = append(setEnvVars, varAndValue[0])
-
-		evaluatedEnvVars = append(evaluatedEnvVars, cliEnvVar)
-	}
-
-	// Add lazily evaluated environment variables if they have not
-	// already been set via the CLI --env option.
-	for _, lazyEnvVar := range ListOfLazyEvaluatedEnvVars {
-		alreadySet := false
-		for _, setEnvVar := range setEnvVars {
-			if setEnvVar == lazyEnvVar {
-				alreadySet = true
-
-				break
-			}
-		}
-
-		if !alreadySet {
-			value, err := GetEnvironmentVariable(lazyEnvVar)
-			if err != nil {
-				return nil, err
-			}
-			evaluatedEnvVars = append(evaluatedEnvVars, lazyEnvVar+"="+value)
-		}
-	}
-
-	return evaluatedEnvVars, nil
-}
-
 // Open a safe wrapper of os.Open.
 func Open(name string) (*os.File, error) {
 	return os.Open(filepath.Clean(name))
@@ -628,7 +456,7 @@ func WriteFileWithContent(filePath string, content []byte) error {
 	fileDir := path.Dir(filePath)
 
 	// Create dir if not present
-	err := os.MkdirAll(fileDir, io2.FilePerm700)
+	err := os.MkdirAll(fileDir, io2.FilePerm755)
 	if err != nil {
 		return fmt.Errorf("could not create dir for file "+filePath+": %w", err)
 	}
@@ -745,3 +573,23 @@ func NavigateConfigTree(current interface{}, nodes []string) (interface{}, error
 		return nil, errors.New("invalid node type in configuration")
 	}
 }
+
+// IToInt32 attempts to convert safely an int to an int32.
+func IToInt32(x int) (*int32, error) {
+	if x < math.MinInt32 || x > math.MaxInt32 {
+		return nil, fmt.Errorf("integer overflow casting to int32 type")
+	}
+	casted := int32(x)
+
+	return &casted, nil
+}
+
+// IToInt8 attempts to convert safely an int to an int8.
+func IToInt8(x int) (*int8, error) {
+	if x < math.MinInt8 || x > math.MaxInt8 {
+		return nil, fmt.Errorf("integer overflow casting to int8 type")
+	}
+	casted := int8(x)
+
+	return &casted, nil
+}
